==> ltrace_0.3.32.tar.gz: ltrace-0.3.32/sysdeps/linux-gnu/s390/syscallent.h <==
	"0",                               /* 0 */
	"exit",                            /* 1 */
	"fork",                            /* 2 */
	"read",                            /* 3 */
	"write",                           /* 4 */
	"open",                            /* 5 */
	"close",                           /* 6 */
	"7",                               /* 7 */
	"creat",                           /* 8 */
	"link",                            /* 9 */
	"unlink",                          /* 10 */
	"execve",                          /* 11 */
	"chdir",                           /* 12 */
	"time",                            /* 13 */
	"mknod",                           /* 14 */
	"chmod",                           /* 15 */
	"lchown",                          /* 16 */
	"17",                              /* 17 */
	"18",                              /* 18 */
	"lseek",                           /* 19 */
	"getpid",                          /* 20 */
	"mount",                           /* 21 */
	"umount",                          /* 22 */
	"setuid",                          /* 23 */
	"getuid",                          /* 24 */
	"stime",                           /* 25 */
	"ptrace",                          /* 26 */
	"alarm",                           /* 27 */
	"28",                              /* 28 */
	"pause",                           /* 29 */
	"utime",                           /* 30 */
	"31",                              /* 31 */
	"32",                              /* 32 */
	"access",                          /* 33 */
	"nice",                            /* 34 */
	"35",                              /* 35 */
	"sync",                            /* 36 */
	"kill",                            /* 37 */
	"rename",                          /* 38 */
	"mkdir",                           /* 39 */
	"rmdir",                           /* 40 */
	"dup",                             /* 41 */
	"pipe",                            /* 42 */
	"times",                           /* 43 */
	"44",                              /* 44 */
	"brk",                             /* 45 */
	"setgid",                          /* 46 */
	"getgid",                          /* 47 */
	"signal",                          /* 48 */
	"geteuid",                         /* 49 */
	"getegid",                         /* 50 */
	"acct",                            /* 51 */
	"umount2",                         /* 52 */
	"53",                              /* 53 */
	"ioctl",                           /* 54 */
	"fcntl",                           /* 55 */
	"56",                              /* 56 */
	"setpgid",                         /* 57 */
	"58",                              /* 58 */
	"59",                              /* 59 */
	"umask",                           /* 60 */
	"chroot",                          /* 61 */
	"ustat",                           /* 62 */
	"dup2",                            /* 63 */
	"getppid",                         /* 64 */
	"getpgrp",                         /* 65 */
	"setsid",                          /* 66 */
	"sigaction",                       /* 67 */
	"68",                              /* 68 */
	"69",                              /* 69 */
	"setreuid",                        /* 70 */
	"setregid",                        /* 71 */
	"sigsuspend",                      /* 72 */
	"sigpending",                      /* 73 */
	"sethostname",                     /* 74 */
	"setrlimit",                       /* 75 */
	"getrlimit",                       /* 76 */
	"getrusage",                       /* 77 */
	"gettimeofday",                    /* 78 */
	"settimeofday",                    /* 79 */
	"getgroups",                       /* 80 */
	"setgroups",                       /* 81 */
	"82",                              /* 82 */
	"symlink",                         /* 83 */
	"84",                              /* 84 */
	"readlink",                        /* 85 */
	"uselib",                          /* 86 */
	"swapon",                          /* 87 */
	"reboot",                          /* 88 */
	"readdir",                         /* 89 */
	"mmap",                            /* 90 */
	"munmap",                          /* 91 */
	"truncate",                        /* 92 */
	"ftruncate",                       /* 93 */
	"fchmod",                          /* 94 */
	"fchown",                          /* 95 */
	"getpriority",                     /* 96 */
	"setpriority",                     /* 97 */
	"98",                              /* 98 */
	"statfs",                          /* 99 */
	"fstatfs",                         /* 100 */
	"ioperm",                          /* 101 */
	"socketcall",                      /* 102 */
	"syslog",                          /* 103 */
	"setitimer",                       /* 104 */
	"getitimer",                       /* 105 */
	"stat",                            /* 106 */
	"lstat",                           /* 107 */
	"fstat",                           /* 108 */
	"109",                             /* 109 */
	"110",                             /* 110 */
	"vhangup",                         /* 111 */
	"idle",                            /* 112 */
	"113",                             /* 113 */
	"wait4",                           /* 114 */
	"swapoff",                         /* 115 */
	"sysinfo",                         /* 116 */
	"ipc",                             /* 117 */
	"fsync",                           /* 118 */
	"sigreturn",                       /* 119 */
	"clone",                           /* 120 */
	"setdomainname",                   /* 121 */
	"uname",                           /* 122 */
	"123",                             /* 123 */
	"adjtimex",                        /* 124 */
	"mprotect",                        /* 125 */
	"sigprocmask",                     /* 126 */
	"create_module",                   /* 127 */
	"init_module",                     /* 128 */
	"delete_module",                   /* 129 */
	"get_kernel_syms",                 /* 130 */
	"quotactl",                        /* 131 */
	"getpgid",                         /* 132 */
	"fchdir",                          /* 133 */
	"bdflush",                         /* 134 */
	"sysfs",                           /* 135 */
	"personality",                     /* 136 */
	"afs_syscall",                     /* 137 */
	"setfsuid",                        /* 138 */
	"setfsgid",                        /* 139 */
	"_llseek",                         /* 140 */
	"getdents",                        /* 141 */
	"_newselect",                      /* 142 */
	"flock",                           /* 143 */
	"msync",                           /* 144 */
	"readv",                           /* 145 */
	"writev",                          /* 146 */
	"getsid",                          /* 147 */
	"fdatasync",                       /* 148 */
	"_sysctl",                         /* 149 */
	"mlock",                           /* 150 */
	"munlock",                         /* 151 */
	"mlockall",                        /* 152 */
	"munlockall",                      /* 153 */
	"sched_setparam",                  /* 154 */
	"sched_getparam",                  /* 155 */
	"sched_setscheduler",              /* 156 */
	"sched_getscheduler",              /* 157 */
	"sched_yield",                     /* 158 */
	"sched_get_priority_max",          /* 159 */
	"sched_get_priority_min",          /* 160 */
	"sched_rr_get_interval",           /* 161 */
	"nanosleep",                       /* 162 */
	"mremap",                          /* 163 */
	"setresuid",                       /* 164 */
	"getresuid",                       /* 165 */
	"166",                             /* 166 */
	"query_module",                    /* 167 */
	"poll",                            /* 168 */
	"nfsservctl",                      /* 169 */
	"setresgid",                       /* 170 */
	"getresgid",                       /* 171 */
	"prctl",                           /* 172 */
	"rt_sigreturn",                    /* 173 */
	"rt_sigaction",                    /* 174 */
	"rt_sigprocmask",                  /* 175 */
	"rt_sigpending",                   /* 176 */
	"rt_sigtimedwait",                 /* 177 */
	"rt_sigqueueinfo",                 /* 178 */
	"rt_sigsuspend",                   /* 179 */
	"pread",                           /* 180 */
	"pwrite",                          /* 181 */
	"chown",                           /* 182 */
	"getcwd",                          /* 183 */
	"capget",                          /* 184 */
	"capset",                          /* 185 */
	"sigaltstack",                     /* 186 */
	"sendfile",                        /* 187 */
	"getpmsg",                         /* 188 */
	"putpmsg",                         /* 189 */
	"vfork",                           /* 190 */
	"ugetrlimit",                      /* 191 */
	"mmap2",                           /* 192 */
	"truncate64",                      /* 193 */
	"ftruncate64",                     /* 194 */
	"stat64",                          /* 195 */
	"lstat64",                         /* 196 */
	"fstat64",                         /* 197 */
	"lchown32",                        /* 198 */
	"getuid32",                        /* 199 */
	"getgid32",                        /* 200 */
	"geteuid32",                       /* 201 */
	"getegid32",                       /* 202 */
	"setreuid32",                      /* 203 */
	"setregid32",                      /* 204 */
	"getgroups32",                     /* 205 */
	"setgroups32",                     /* 206 */
	"fchown32",                        /* 207 */
	"setresuid32",                     /* 208 */
	"getresuid32",                     /* 209 */
	"setresgid32",                     /* 210 */
	"getresgid32",                     /* 211 */
	"chown32",                         /* 212 */
	"setuid32",                        /* 213 */
	"setgid32",                        /* 214 */
	"setfsuid32",                      /* 215 */
	"setfsgid32",                      /* 216 */
	"pivot_root",                      /* 217 */
	"mincore",                         /* 218 */
	"madvise",                         /* 219 */
	"getdents64",                      /* 220 */
	"fcntl64",                         /* 221 */
	"readahead",                       /* 222 */
	"223",                             /* 223 */
	"setxattr",                        /* 224 */
	"lsetxattr",                       /* 225 */
	"fsetxattr",                       /* 226 */
	"getxattr",                        /* 227 */
	"lgetxattr",                       /* 228 */
	"fgetxattr",                       /* 229 */
	"listxattr",                       /* 230 */
	"llistxattr",                      /* 231 */
	"flistxattr",                      /* 232 */
	"removexattr",                     /* 233 */
	"lremovexattr",                    /* 234 */
	"fremovexattr",                    /* 235 */
	"gettid",                          /* 236 */
	"tkill",                           /* 237 */

==> ltrace_0.3.36.orig.tar.gz: ltrace-0.3.36/sysdeps/linux-gnu/s390/syscallent.h <==
	"0",                               /* 0 */
	"exit",                            /* 1 */
	"fork",                            /* 2 */
	"read",                            /* 3 */
	"write",                           /* 4 */
	"open",                            /* 5 */
	"close",                           /* 6 */
	"7",                               /* 7 */
	"creat",                           /* 8 */
	"link",                            /* 9 */
	"unlink",                          /* 10 */
	"execve",                          /* 11 */
	"chdir",                           /* 12 */
	"time",                            /* 13 */
	"mknod",                           /* 14 */
	"chmod",                           /* 15 */
	"lchown",                          /* 16 */
	"17",                              /* 17 */
	"18",                              /* 18 */
	"lseek",                           /* 19 */
	"getpid",                          /* 20 */
	"mount",                           /* 21 */
	"umount",                          /* 22 */
	"setuid",                          /* 23 */
	"getuid",                          /* 24 */
	"stime",                           /* 25 */
	"ptrace",                          /* 26 */
	"alarm",                           /* 27 */
	"28",                              /* 28 */
	"pause",                           /* 29 */
	"utime",                           /* 30 */
	"31",                              /* 31 */
	"32",                              /* 32 */
	"access",                          /* 33 */
	"nice",                            /* 34 */
	"35",                              /* 35 */
	"sync",                            /* 36 */
	"kill",                            /* 37 */
	"rename",                          /* 38 */
	"mkdir",                           /* 39 */
	"rmdir",                           /* 40 */
	"dup",                             /* 41 */
	"pipe",                            /* 42 */
	"times",                           /* 43 */
	"44",                              /* 44 */
	"brk",                             /* 45 */
	"setgid",                          /* 46 */
	"getgid",                          /* 47 */
	"signal",                          /* 48 */
	"geteuid",                         /* 49 */
	"getegid",                         /* 50 */
	"acct",                            /* 51 */
	"umount2",                         /* 52 */
	"53",                              /* 53 */
	"ioctl",                           /* 54 */
	"fcntl",                           /* 55 */
	"56",                              /* 56 */
	"setpgid",                         /* 57 */
	"58",                              /* 58 */
	"59",                              /* 59 */
	"umask",                           /* 60 */
	"chroot",                          /* 61 */
	"ustat",                           /* 62 */
	"dup2",                            /* 63 */
	"getppid",                         /* 64 */
	"getpgrp",                         /* 65 */
	"setsid",                          /* 66 */
	"sigaction",                       /* 67 */
	"68",                              /* 68 */
	"69",                              /* 69 */
	"setreuid",                        /* 70 */
	"setregid",                        /* 71 */
	"sigsuspend",                      /* 72 */
	"sigpending",                      /* 73 */
	"sethostname",                     /* 74 */
	"setrlimit",                       /* 75 */
	"getrlimit",                       /* 76 */
	"getrusage",                       /* 77 */
	"gettimeofday",                    /* 78 */
	"settimeofday",                    /* 79 */
	"getgroups",                       /* 80 */
	"setgroups",                       /* 81 */
	"82",                              /* 82 */
	"symlink",                         /* 83 */
	"84",                              /* 84 */
	"readlink",                        /* 85 */
	"uselib",                          /* 86 */
	"swapon",                          /* 87 */
	"reboot",                          /* 88 */
	"readdir",                         /* 89 */
	"mmap",                            /* 90 */
	"munmap",                          /* 91 */
	"truncate",                        /* 92 */
	"ftruncate",                       /* 93 */
	"fchmod",                          /* 94 */
	"fchown",                          /* 95 */
	"getpriority",                     /* 96 */
	"setpriority",                     /* 97 */
	"98",                              /* 98 */
	"statfs",                          /* 99 */
	"fstatfs",                         /* 100 */
	"ioperm",                          /* 101 */
	"socketcall",                      /* 102 */
	"syslog",                          /* 103 */
	"setitimer",                       /* 104 */
	"getitimer",                       /* 105 */
	"stat",                            /* 106 */
	"lstat",                           /* 107 */
	"fstat",                           /* 108 */
	"109",                             /* 109 */
	"110",                             /* 110 */
	"vhangup",                         /* 111 */
	"idle",                            /* 112 */
	"113",                             /* 113 */
	"wait4",                           /* 114 */
	"swapoff",                         /* 115 */
	"sysinfo",                         /* 116 */
	"ipc",                             /* 117 */
	"fsync",                           /* 118 */
	"sigreturn",                       /* 119 */
	"clone",                           /* 120 */
	"setdomainname",                   /* 121 */
	"uname",                           /* 122 */
	"123",                             /* 123 */
	"adjtimex",                        /* 124 */
	"mprotect",                        /* 125 */
	"sigprocmask",                     /* 126 */
	"create_module",                   /* 127 */
	"init_module",                     /* 128 */
	"delete_module",                   /* 129 */
	"get_kernel_syms",                 /* 130 */
	"quotactl",                        /* 131 */
	"getpgid",                         /* 132 */
	"fchdir",                          /* 133 */
	"bdflush",                         /* 134 */
	"sysfs",                           /* 135 */
	"personality",                     /* 136 */
	"afs_syscall",                     /* 137 */
	"setfsuid",                        /* 138 */
	"setfsgid",                        /* 139 */
	"_llseek",                         /* 140 */
	"getdents",                        /* 141 */
	"_newselect",                      /* 142 */
	"flock",                           /* 143 */
	"msync",                           /* 144 */
	"readv",                           /* 145 */
	"writev",                          /* 146 */
	"getsid",                          /* 147 */
	"fdatasync",                       /* 148 */
	"_sysctl",                         /* 149 */
	"mlock",                           /* 150 */
	"munlock",                         /* 151 */
	"mlockall",                        /* 152 */
	"munlockall",                      /* 153 */
	"sched_setparam",                  /* 154 */
	"sched_getparam",                  /* 155 */
	"sched_setscheduler",              /* 156 */
	"sched_getscheduler",              /* 157 */
	"sched_yield",                     /* 158 */
	"sched_get_priority_max",          /* 159 */
	"sched_get_priority_min",          /* 160 */
	"sched_rr_get_interval",           /* 161 */
	"nanosleep",                       /* 162 */
	"mremap",                          /* 163 */
	"setresuid",                       /* 164 */
	"getresuid",                       /* 165 */
	"166",                             /* 166 */
	"query_module",                    /* 167 */
	"poll",                            /* 168 */
	"nfsservctl",                      /* 169 */
	"setresgid",                       /* 170 */
	"getresgid",                       /* 171 */
	"prctl",                           /* 172 */
	"rt_sigreturn",                    /* 173 */
	"rt_sigaction",                    /* 174 */
	"rt_sigprocmask",                  /* 175 */
	"rt_sigpending",                   /* 176 */
	"rt_sigtimedwait",                 /* 177 */
	"rt_sigqueueinfo",                 /* 178 */
	"rt_sigsuspend",                   /* 179 */
	"pread",                           /* 180 */
	"pwrite",                          /* 181 */
	"chown",                           /* 182 */
	"getcwd",                          /* 183 */
	"capget",                          /* 184 */
	"capset",                          /* 185 */
	"sigaltstack",                     /* 186 */
	"sendfile",                        /* 187 */
	"getpmsg",                         /* 188 */
	"putpmsg",                         /* 189 */
	"vfork",                           /* 190 */
	"ugetrlimit",                      /* 191 */
	"mmap2",                           /* 192 */
	"truncate64",                      /* 193 */
	"ftruncate64",                     /* 194 */
	"stat64",                          /* 195 */
	"lstat64",                         /* 196 */
	"fstat64",                         /* 197 */
	"lchown32",                        /* 198 */
	"getuid32",                        /* 199 */
	"getgid32",                        /* 200 */
	"geteuid32",                       /* 201 */
	"getegid32",                       /* 202 */
	"setreuid32",                      /* 203 */
	"setregid32",                      /* 204 */
	"getgroups32",                     /* 205 */
	"setgroups32",                     /* 206 */
	"fchown32",                        /* 207 */
	"setresuid32",                     /* 208 */
	"getresuid32",                     /* 209 */
	"setresgid32",                     /* 210 */
	"getresgid32",                     /* 211 */
	"chown32",                         /* 212 */
	"setuid32",                        /* 213 */
	"setgid32",                        /* 214 */
	"setfsuid32",                      /* 215 */
	"setfsgid32",                      /* 216 */
	"pivot_root",                      /* 217 */
	"mincore",                         /* 218 */
	"madvise",                         /* 219 */
	"getdents64",                      /* 220 */
	"fcntl64",                         /* 221 */
	"readahead",                       /* 222 */
	"sendfile64",                      /* 223 */
	"setxattr",                        /* 224 */
	"lsetxattr",                       /* 225 */
	"fsetxattr",                       /* 226 */
	"getxattr",                        /* 227 */
	"lgetxattr",                       /* 228 */
	"fgetxattr",                       /* 229 */
	"listxattr",                       /* 230 */
	"llistxattr",                      /* 231 */
	"flistxattr",                      /* 232 */
	"removexattr",                     /* 233 */
	"lremovexattr",                    /* 234 */
	"fremovexattr",                    /* 235 */
	"gettid",                          /* 236 */
	"tkill",                           /* 237 */
	"futex",                           /* 238 */
	"sched_setaffinity",               /* 239 */
	"sched_getaffinity",               /* 240 */
	"241",                             /* 241 */
	"242",                             /* 242 */
	"io_setup",                        /* 243 */
	"io_destroy",                      /* 244 */
	"io_getevents",                    /* 245 */
	"io_submit",                       /* 246 */
	"io_cancel",                       /* 247 */
	"exit_group",                      /* 248 */
	"epoll_create",                    /* 249 */
	"epoll_ctl",                       /* 250 */
	"epoll_wait",                      /* 251 */
	"set_tid_address",                 /* 252 */
	"fadvise64",                       /* 253 */
	"timer_create",                    /* 254 */
	"timer_settime",                   /* 255 */
	"timer_gettime",                   /* 256 */
	"timer_getoverrun",                /* 257 */
	"timer_delete",                    /* 258 */
	"clock_settime",                   /* 259 */
	"clock_gettime",                   /* 260 */
	"clock_getres",                    /* 261 */
	"clock_nanosleep",                 /* 262 */
	"263",                             /* 263 */
	"fadvise64_64",                    /* 264 */
	"statfs64",                        /* 265 */
	"fstatfs64",                       /* 266 */
	"267",                             /* 267 */
	"268",                             /* 268 */
	"269",                             /* 269 */
	"270",                             /* 270 */
	"mq_open",                         /* 271 */
	"mq_unlink",                       /* 272 */
	"mq_timedsend",                    /* 273 */
	"mq_timedreceive",                 /* 274 */
	"mq_notify",                       /* 275 */
	"mq_getsetattr",                   /* 276 */
